==> apache-servicecomb-java-chassis-distribution-1.1.0-src.zip: apache-servicecomb-java-chassis-distribution-1.1.0-src/handlers/handler-flowcontrol-qps/src/test/java/org/apache/servicecomb/qps/TestConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.qps;

import org.apache.servicecomb.foundation.test.scaffolding.config.ArchaiusUtils;
import org.junit.AfterClass;
import org.junit.Assert;
import org.junit.BeforeClass;
import org.junit.Test;

/**
 *
 *
 */
public class TestConfig {
  @BeforeClass
  public static void classSetup() {
    ArchaiusUtils.resetConfig();
  }

  @AfterClass
  public static void classTeardown() {
    ArchaiusUtils.resetConfig();
  }

  @Test
  public void testEnabled() {
    Config.INSTANCE = new Config();

    Assert.assertEquals(true, Config.INSTANCE.isProviderEnabled());
    ArchaiusUtils.updateProperty(Config.PROVIDER_ENABLED, false);
    Assert.assertEquals(false, Config.INSTANCE.isProviderEnabled());

    ArchaiusUtils.updateProperty(Config.PROVIDER_ENABLED, null);
    Assert.assertEquals(true, Config.INSTANCE.isProviderEnabled());

    Assert.assertEquals(true, Config.INSTANCE.isConsumerEnabled());
    ArchaiusUtils.updateProperty(Config.CONSUMER_ENABLED, false);
    Assert.assertEquals(false, Config.INSTANCE.isConsumerEnabled());

    ArchaiusUtils.updateProperty(Config.CONSUMER_ENABLED, null);
    Assert.assertEquals(true, Config.INSTANCE.isConsumerEnabled());
  }
}

==> apache-servicecomb-java-chassis-distribution-1.3.0-src.zip: apache-servicecomb-java-chassis-distribution-1.3.0-src/handlers/handler-flowcontrol-qps/src/test/java/org/apache/servicecomb/qps/TestConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.qps;

import org.apache.servicecomb.foundation.test.scaffolding.config.ArchaiusUtils;
import org.junit.AfterClass;
import org.junit.Assert;
import org.junit.BeforeClass;
import org.junit.Test;

/**
 *
 *
 */
public class TestConfig {
  @BeforeClass
  public static void classSetup() {
    ArchaiusUtils.resetConfig();
  }

  @AfterClass
  public static void classTeardown() {
    ArchaiusUtils.resetConfig();
  }

  @Test
  public void testEnabled() {
    Config.INSTANCE = new Config();

    Assert.assertEquals(true, Config.INSTANCE.isProviderEnabled());
    ArchaiusUtils.setProperty(Config.PROVIDER_ENABLED, false);
    Assert.assertEquals(false, Config.INSTANCE.isProviderEnabled());

    ArchaiusUtils.setProperty(Config.PROVIDER_ENABLED, null);
    Assert.assertEquals(true, Config.INSTANCE.isProviderEnabled());

    Assert.assertEquals(true, Config.INSTANCE.isConsumerEnabled());
    ArchaiusUtils.setProperty(Config.CONSUMER_ENABLED, false);
    Assert.assertEquals(false, Config.INSTANCE.isConsumerEnabled());

    ArchaiusUtils.setProperty(Config.CONSUMER_ENABLED, null);
    Assert.assertEquals(true, Config.INSTANCE.isConsumerEnabled());
  }
}
